Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(815)

Unified Diff: runtime/vm/code_patcher.h

Issue 17723002: Remove skip_static_calls_ as it uses an obsolete way to check for uncalled static calls. Will be re… (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/code_generator.cc ('k') | runtime/vm/code_patcher_arm.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/code_patcher.h
===================================================================
--- runtime/vm/code_patcher.h (revision 24432)
+++ runtime/vm/code_patcher.h (working copy)
@@ -56,9 +56,11 @@
const Code& code,
ICData* ic_data);
- // Return target of an unoptimized static call (calls target via a stub).
- static RawFunction* GetUnoptimizedStaticCallTargetAt(uword return_address,
- const Code& code);
+ // Return target of an unoptimized static call and its ICData object
+ // (calls target via a stub).
+ static RawFunction* GetUnoptimizedStaticCallAt(uword return_address,
+ const Code& code,
+ ICData* ic_data);
// Return the arguments descriptor array of the closure call
// before the given return address.
« no previous file with comments | « runtime/vm/code_generator.cc ('k') | runtime/vm/code_patcher_arm.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698